{% extends 'content/gallery/p.classic.html' %}

{% load feincms_thumbnail %}

{% block caption %}<span class="gallery_image_caption">{{ picture.translation.caption }}</span>{% endblock %}

{% block image-original %}{{ picture.file.name|thumbnail:'960x650' }}{% endblock %}

{% block image-remaining %}{{ picture.file.name|thumbnail:'960x650' }}{% endblock %}