.simple.slideshow {
    position:relative;
    height:420px;
    width: 590px;
    margin: 18px auto;
}

.simple.slideshow div {
    position:absolute;
    top:0;
    left:0;
    z-index:8;
    opacity:0.0;
}

.simple.slideshow div.active {
    z-index:10;
    opacity:1.0;
}

.simple.slideshow div.last-active {
    z-index:9;
}